@@ -2,7 +2,7 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.17'
+__version__ = '0.1.20'
 
 import datetime
 import logstash
@@ -26,6 +26,7 @@ def logsstash_logging(args):
                                                          version=1,
                                                          message_type="driver-parser"))
 
+
 def packet_summary(packet):
     ip_src = None
     ip_dst = None
@@ -75,7 +76,9 @@ def parse_file(args):
                     terminal_type = _terminal_type
                     terminal_serial = _terminal_serial
 
-        if not re.match("\d{15}", terminal_serial):
+        if not re.match("\d{15}", terminal_serial) and \
+            not (re.match("\d{7}", terminal_serial) and terminal_type == "Cellocator") and \
+            not (re.match("\d{11}", terminal_serial) and terminal_type == "Bronco"):
             continue
 
         payload = DataOut(terminal_serial,
